{% extends "detail.html" %}
{% load static %}
{% load boolicontag %}

{% block content %}
<table class="table table-hover">
  <tr>
    <th colspan="2" id="summary"><img src="{% static "svg/summary.svg" %}" width="30" height="30" alt="Summary">&nbsp;<a
        href="#">Summary</a></th>
  </tr>
  <tr>
    <td>Process name</td>
    <td>{{ object.name }}</td>
  </tr>
  {% if object.colour is not None %}
  <tr>
    <td>Colour</td>
    <td>{{ object.colour|boolicontag }}</td>
  </tr>
  {% endif %}
  {% if object.positive is not None %}
  <tr>
    <td>Positive</td>
    <td>{{ object.positive|boolicontag }}</td>
  </tr>
  {% endif %}
</table>
{% endblock %}
