# Generated by Django 3.2.13 on 2022-05-24 20:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0131_auto_20220420_1535'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='other_names',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='other_names',
        ),
    ]
