# Generated by Django 3.2.12 on 2022-04-20 15:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0130_filter_colour'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicallensmodel',
            name='purpose',
            field=models.CharField(blank=True, choices=[('Camera', 'Camera'), ('Enlarger', 'Enlarger'), ('Projector', 'Projector')], help_text='Intended purposes of lens', max_length=16, null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='purpose',
            field=models.CharField(blank=True, choices=[('Camera', 'Camera'), ('Enlarger', 'Enlarger'), ('Projector', 'Projector')], help_text='Intended purposes of lens', max_length=16, null=True),
        ),
    ]
